# Changelog

<!--next-version-placeholder-->

## v0.0.5 (2022-03-13)
### Fix
* Setup semantic release ([`b9dcca6`](https://github.com/iamtalhaasghar/googleweather/commit/b9dcca6a7d4019c514ed28391a99a2820e671f15))
